\name{FPERMANOVA}
\alias{FPERMANOVA}
\title{Fast PERMANOVA}
\description{
This function calculates the PERMANOVA p-value in a fast and permutation-free manner.
}
\usage{ FPERMANOVA(X, D, perbB = 10^6) }
\arguments{
  \item{X}{ Design matrix with predictor variables }
  \item{D}{ Distance matrix based on response variables }
  \item{perbB}{ The number of perbutations/re-samples used for calculating p-value }
}
\details{
It first calculates matrices H and G, where \eqn{H=X(X'X)^{-1}X'} is the projection/hat matrix based on predictor variables, and G is the Gower's centered similarity matrix calculated from distance matrix D based on the procedure described in McArdle and Anderson (2001).  Then, the pseudo-F statistic can be calculated from H and G. \cr 
Instead of calculating the p-value by explicitly drawing permutations and re-calculating the pseudo-F statistic via matrix multiplication, FPERMANOVA studies the distribution of the numerator tr(HG) of the pseudo-F statistic, which is the only part changes across permutations. The permutation distribution of tr(HG) is approxiamted by the Pearson type III distribution by matching the first three moments. Then, replicated samples of tr(HG) are drawn from the appriximated Pearson type III distribution, and are used to calculate resamplings of the pseudo-F statistic. Finally, p-value is calculated by comparing the observed pseudo-F statistic and the re-sampled pseudo-F statistics. 
}
\value{
  \item{F }{Observed tr(HG) statistic}
  \item{mean}{Sample mean of all n! possible permutations of tr(HG)}
  \item{var}{Sample variance of all n! possible permutations of tr(HG)}
  \item{skew}{Sample skewness of all n! possible permutations of tr(HG)}
  \item{pvalue}{P-value of FPERMANVOA based on the perbutated resamples}
}
\references{
	McArdle, B. H. and Anderson, M. J. (2001). Fitting multivariate models to community data: a comment on distance--based redundancy analysis. Ecology, 82, 290-297.  \cr
	Zhan, X. and Wu, M. C. (2016). FPERMANOVA: A fast permutation-free PERMANOVA procedure. Technical Report. \cr
	R package PearsonDS version 0.98.
}


\examples{
X=matrix(rnorm(20*3,0,1),20,3)
Y=matrix(rnorm(20*100,0,1),20,100)
D=as.matrix(dist(Y, method="euclidean"))
FPERMANOVA(X,D,perbB=10^5)
}

